@@ -14,19 +14,18 @@
 # under the License.
 
 import os
+from unittest import mock
 import uuid
 
 import fixtures
 from gnocchiclient import exceptions as gnocchi_exc
 from keystoneauth1 import exceptions as ka_exceptions
-import mock
 from oslo_config import fixture as config_fixture
 from oslo_utils import fileutils
 from oslo_utils import fixture as utils_fixture
 from oslo_utils import netutils
 from oslo_utils import timeutils
 import requests
-import six
 from stevedore import extension
 import testscenarios
 
@@ -281,8 +280,7 @@ class PublisherTest(base.BaseTestCase):
                     ]
 
         for content in contents:
-            if six.PY3:
-                content = content.encode('utf-8')
+            content = content.encode('utf-8')
 
             temp = fileutils.write_to_tempfile(content=content,
                                                prefix='gnocchi_resources',
@@ -352,6 +350,27 @@ class PublisherTest(base.BaseTestCase):
         d.publish_samples(samples)
         self.assertEqual(0, len(fake_batch.call_args[0][1]))
 
+    @mock.patch('ceilometer.publisher.gnocchi.GnocchiPublisher'
+                '.batch_measures')
+    def test_unhandled_meter_with_no_resource_id(self, fake_batch):
+        samples = [sample.Sample(
+            name='unknown.meter',
+            unit='GB',
+            type=sample.TYPE_GAUGE,
+            volume=2,
+            user_id='test_user',
+            project_id='test_project',
+            source='openstack',
+            timestamp='2014-05-08 20:23:48.028195',
+            resource_id=None,
+            resource_metadata={}
+        )]
+        url = netutils.urlsplit("gnocchi://")
+        d = gnocchi.GnocchiPublisher(self.conf.conf, url)
+        d._already_checked_archive_policies = True
+        d.publish_samples(samples)
+        self.assertEqual(0, len(fake_batch.call_args[0][1]))
+
 
 class MockResponse(mock.NonCallableMock):
     def __init__(self, code):
@@ -662,6 +681,8 @@ class PublisherWorkflowTest(base.BaseTestCase,
         expected_debug = [
             mock.call('filtered project found: %s',
                       'a2d42c23-d518-46b6-96ab-3fba2e146859'),
+            mock.call('Processing sample [%s] for resource ID [%s].',
+                      self.sample, resource_id),
         ]
 
         measures_posted = False
